@@ -1,10 +1,14 @@
-# Copyrights 1995-2017 by [Mark Overmeer <perl@overmeer.net>].
+# Copyrights 1995-2018 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of the bundle MailTools.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md for Copyright.
+# Licensed under the same terms as Perl itself.
+
 package Mail::Header;
 use vars '$VERSION';
-$VERSION = '2.19';
+$VERSION = '2.20';
 
 
 use strict;
@@ -74,7 +78,7 @@ sub _fold_line
     my $min = int($maxlen * 4 / 5) - 4;
 
     $_[0] =~ s/[\r\n]+//og;        # Remove new-lines
-    $_[0] =~ s/\s*\Z/\n/so;        # End line with a EOLN
+    $_[0] =~ s/\s*\Z/\n/so;        # End line with an EOLN
 
     return if $_[0] =~ /^From\s/io;
 
